namespace efl { namespace canvas { namespace text { 
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Cursor::text_object_get() const
{
    ::Efl_Canvas_Object const* __return_value =  ::efl_canvas_text_cursor_text_object_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::text_object_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type tb) const
{
    ::efl_canvas_text_cursor_text_object_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object const*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(tb));
}
inline ::efl::eolian::return_traits<int>::type Cursor::position_get() const
{
   int __return_value =  ::efl_canvas_text_cursor_position_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::position_set( ::efl::eolian::in_traits<int>::type position) const
{
    ::efl_canvas_text_cursor_position_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(position));
}
inline ::efl::eolian::return_traits<bool>::type Cursor::geometry_get( ::efl::eolian::in_traits<Efl_Canvas_Text_Cursor_Type>::type ctype,  ::efl::eolian::out_traits<Evas_Coord>::type cx,  ::efl::eolian::out_traits<Evas_Coord>::type cy,  ::efl::eolian::out_traits<Evas_Coord>::type cw,  ::efl::eolian::out_traits<Evas_Coord>::type ch,  ::efl::eolian::out_traits<Evas_Coord>::type cx2,  ::efl::eolian::out_traits<Evas_Coord>::type cy2,  ::efl::eolian::out_traits<Evas_Coord>::type cw2,  ::efl::eolian::out_traits<Evas_Coord>::type ch2) const
{
   Evas_Coord __out_param_cx = {};
   Evas_Coord __out_param_cy = {};
   Evas_Coord __out_param_cw = {};
   Evas_Coord __out_param_ch = {};
   Evas_Coord __out_param_cx2 = {};
   Evas_Coord __out_param_cy2 = {};
   Evas_Coord __out_param_cw2 = {};
   Evas_Coord __out_param_ch2 = {};
   Eina_Bool __return_value =  ::efl_canvas_text_cursor_geometry_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Canvas_Text_Cursor_Type,  ::efl::eolian::in_traits<Efl_Canvas_Text_Cursor_Type>::type>(ctype)
      , & __out_param_cx
      , & __out_param_cy
      , & __out_param_cw
      , & __out_param_ch
      , & __out_param_cx2
      , & __out_param_cy2
      , & __out_param_cw2
      , & __out_param_ch2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cx, __out_param_cx);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cy, __out_param_cy);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cw, __out_param_cw);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(ch, __out_param_ch);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cx2, __out_param_cx2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cy2, __out_param_cy2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cw2, __out_param_cw2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(ch2, __out_param_ch2);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Eina_Unicode>::type Cursor::content_get() const
{
   Eina_Unicode __return_value =  ::efl_canvas_text_cursor_content_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Unicode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::copy( ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type src) const
{
    ::efl_canvas_text_cursor_copy(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Text_Cursor const*,  ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type>(src));
}
inline ::efl::eolian::return_traits<int>::type Cursor::text_insert( ::efl::eolian::in_traits< ::efl::eina::string_view>::type text) const
{
   int __return_value =  ::efl_canvas_text_cursor_text_insert(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(text));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::char_prev() const
{
    ::efl_canvas_text_cursor_char_prev(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::char_next() const
{
    ::efl_canvas_text_cursor_char_next(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::char_delete() const
{
    ::efl_canvas_text_cursor_char_delete(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_first() const
{
    ::efl_canvas_text_cursor_paragraph_first(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_last() const
{
    ::efl_canvas_text_cursor_paragraph_last(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_next() const
{
    ::efl_canvas_text_cursor_paragraph_next(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_prev() const
{
    ::efl_canvas_text_cursor_paragraph_prev(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_char_first() const
{
    ::efl_canvas_text_cursor_paragraph_char_first(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_char_last() const
{
    ::efl_canvas_text_cursor_paragraph_char_last(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::word_start() const
{
    ::efl_canvas_text_cursor_word_start(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::word_end() const
{
    ::efl_canvas_text_cursor_word_end(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::line_char_first() const
{
    ::efl_canvas_text_cursor_line_char_first(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::line_char_last() const
{
    ::efl_canvas_text_cursor_line_char_last(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::line_jump_by( ::efl::eolian::in_traits<int>::type by) const
{
    ::efl_canvas_text_cursor_line_jump_by(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(by));
}
inline ::efl::eolian::return_traits<int>::type Cursor::compare( ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type cur) const
{
   int __return_value =  ::efl_canvas_text_cursor_compare(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Text_Cursor const*,  ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type>(cur));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::equal( ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type cur) const
{
   Eina_Bool __return_value =  ::efl_canvas_text_cursor_equal(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Text_Cursor const*,  ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type>(cur));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::coord_set( ::efl::eolian::in_traits<Evas_Coord>::type x,  ::efl::eolian::in_traits<Evas_Coord>::type y) const
{
    ::efl_canvas_text_cursor_coord_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(x)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(y));
}
} } } 
namespace eo_cxx {
namespace efl { namespace canvas { namespace text { 
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Cursor::text_object_get() const
{
    ::Efl_Canvas_Object const* __return_value =  ::efl_canvas_text_cursor_text_object_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::text_object_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type tb) const
{
    ::efl_canvas_text_cursor_text_object_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object const*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(tb));
}
inline ::efl::eolian::return_traits<int>::type Cursor::position_get() const
{
   int __return_value =  ::efl_canvas_text_cursor_position_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::position_set( ::efl::eolian::in_traits<int>::type position) const
{
    ::efl_canvas_text_cursor_position_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(position));
}
inline ::efl::eolian::return_traits<bool>::type Cursor::geometry_get( ::efl::eolian::in_traits<Efl_Canvas_Text_Cursor_Type>::type ctype,  ::efl::eolian::out_traits<Evas_Coord>::type cx,  ::efl::eolian::out_traits<Evas_Coord>::type cy,  ::efl::eolian::out_traits<Evas_Coord>::type cw,  ::efl::eolian::out_traits<Evas_Coord>::type ch,  ::efl::eolian::out_traits<Evas_Coord>::type cx2,  ::efl::eolian::out_traits<Evas_Coord>::type cy2,  ::efl::eolian::out_traits<Evas_Coord>::type cw2,  ::efl::eolian::out_traits<Evas_Coord>::type ch2) const
{
   Evas_Coord __out_param_cx = {};
   Evas_Coord __out_param_cy = {};
   Evas_Coord __out_param_cw = {};
   Evas_Coord __out_param_ch = {};
   Evas_Coord __out_param_cx2 = {};
   Evas_Coord __out_param_cy2 = {};
   Evas_Coord __out_param_cw2 = {};
   Evas_Coord __out_param_ch2 = {};
   Eina_Bool __return_value =  ::efl_canvas_text_cursor_geometry_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Canvas_Text_Cursor_Type,  ::efl::eolian::in_traits<Efl_Canvas_Text_Cursor_Type>::type>(ctype)
      , & __out_param_cx
      , & __out_param_cy
      , & __out_param_cw
      , & __out_param_ch
      , & __out_param_cx2
      , & __out_param_cy2
      , & __out_param_cw2
      , & __out_param_ch2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cx, __out_param_cx);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cy, __out_param_cy);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cw, __out_param_cw);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(ch, __out_param_ch);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cx2, __out_param_cx2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cy2, __out_param_cy2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(cw2, __out_param_cw2);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(ch2, __out_param_ch2);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Eina_Unicode>::type Cursor::content_get() const
{
   Eina_Unicode __return_value =  ::efl_canvas_text_cursor_content_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Unicode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::copy( ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type src) const
{
    ::efl_canvas_text_cursor_copy(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Text_Cursor const*,  ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type>(src));
}
inline ::efl::eolian::return_traits<int>::type Cursor::text_insert( ::efl::eolian::in_traits< ::efl::eina::string_view>::type text) const
{
   int __return_value =  ::efl_canvas_text_cursor_text_insert(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(text));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::char_prev() const
{
    ::efl_canvas_text_cursor_char_prev(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::char_next() const
{
    ::efl_canvas_text_cursor_char_next(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::char_delete() const
{
    ::efl_canvas_text_cursor_char_delete(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_first() const
{
    ::efl_canvas_text_cursor_paragraph_first(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_last() const
{
    ::efl_canvas_text_cursor_paragraph_last(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_next() const
{
    ::efl_canvas_text_cursor_paragraph_next(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_prev() const
{
    ::efl_canvas_text_cursor_paragraph_prev(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_char_first() const
{
    ::efl_canvas_text_cursor_paragraph_char_first(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::paragraph_char_last() const
{
    ::efl_canvas_text_cursor_paragraph_char_last(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::word_start() const
{
    ::efl_canvas_text_cursor_word_start(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::word_end() const
{
    ::efl_canvas_text_cursor_word_end(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::line_char_first() const
{
    ::efl_canvas_text_cursor_line_char_first(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::line_char_last() const
{
    ::efl_canvas_text_cursor_line_char_last(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Cursor::line_jump_by( ::efl::eolian::in_traits<int>::type by) const
{
    ::efl_canvas_text_cursor_line_jump_by(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(by));
}
inline ::efl::eolian::return_traits<int>::type Cursor::compare( ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type cur) const
{
   int __return_value =  ::efl_canvas_text_cursor_compare(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Text_Cursor const*,  ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type>(cur));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Cursor::equal( ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type cur) const
{
   Eina_Bool __return_value =  ::efl_canvas_text_cursor_equal(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Text_Cursor const*,  ::efl::eolian::in_traits< ::efl::canvas::text::Cursor>::type>(cur));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Cursor::coord_set( ::efl::eolian::in_traits<Evas_Coord>::type x,  ::efl::eolian::in_traits<Evas_Coord>::type y) const
{
    ::efl_canvas_text_cursor_coord_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(x)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(y));
}
inline efl::canvas::text::Cursor::operator ::efl::canvas::text::Cursor() const { return *static_cast< ::efl::canvas::text::Cursor const*>(static_cast<void const*>(this)); }
inline efl::canvas::text::Cursor::operator ::efl::canvas::text::Cursor&() { return *static_cast< ::efl::canvas::text::Cursor*>(static_cast<void*>(this)); }
inline efl::canvas::text::Cursor::operator ::efl::canvas::text::Cursor const&() const { return *static_cast< ::efl::canvas::text::Cursor const*>(static_cast<void const*>(this)); }
} } } }

